@@ -1,7 +1,7 @@
 /*
- $Id: dbdimp.h,v 1.42 2010/11/06 13:48:42 mpeppler Exp $
+ $Id: dbdimp.h,v 1.44 2013/04/03 20:16:20 mpeppler Exp $
 
- Copyright (c) 1997-2008  Michael Peppler
+ Copyright (c) 1997-2011  Michael Peppler
 
  You may distribute under the terms of either the GNU General Public
  License or the Artistic License, as specified in the Perl README file.
@@ -83,7 +83,7 @@ struct imp_dbh_st {
 	char timeout[64];
 	char scriptName[255];
 	char hostname[255];
-	char database[36];
+	char database[260];
 	char curr_db[36];
 	char tdsLevel[30];
 	char encryptPassword[10];
@@ -144,6 +144,7 @@ typedef struct phs_st {
 	SV *sv;
 	int sv_type;
 	bool is_inout;
+	bool is_boundinout;
 	IV maxlen;
 
 	char *sv_buf;
@@ -156,6 +157,13 @@ typedef struct phs_st {
 
 } phs_t;
 
+/* struct to store pointer to output parameter and returned length */
+typedef struct boundparams_st {
+    phs_t *phs;
+    int len;
+} boundparams_t;
+
+
 /* Define sth implementor data structure */
 struct imp_sth_st {
 	dbih_stc_t com; /* MUST be first element in structure	*/
